@@ -4,9 +4,9 @@
 // except according to those terms.
 
 use std::collections::{HashMap, HashSet};
-use std::fmt::Display;
+use std::fmt::{Debug, Display};
 use std::hash::Hash;
-use std::ops::Deref;
+use std::ops::{AddAssign, Deref};
 use std::str;
 
 use anyhow::Result;
@@ -536,7 +536,7 @@ mod tests {
     }
 }
 
-#[derive(CopyGetters)]
+#[derive(CopyGetters, Debug, Serialize, Deserialize, Clone)]
 pub(crate) struct SimpleCounter<T>
 where
     T: Eq + Hash,
@@ -578,3 +578,15 @@ where
         &self.inner
     }
 }
+
+impl<T> AddAssign for SimpleCounter<T>
+where
+    T: Eq + Hash,
+{
+    fn add_assign(&mut self, rhs: Self) {
+        self.total_count += rhs.total_count;
+        rhs.inner.into_iter().for_each(move |(k, v)| {
+            *self.inner.entry(k).or_insert(0) += v;
+        });
+    }
+}
