@@ -375,7 +375,7 @@ impl Posterior for GenericPosterior {
                 && bias.is_likely(&data.pileups)
         });
 
-        let p = LogProb::ln_sum_exp(
+        LogProb::ln_sum_exp(
             &possible_biases
                 .cartesian_product(vaf_tree)
                 .map(|(biases, node)| {
@@ -384,8 +384,7 @@ impl Posterior for GenericPosterior {
                         + self.density(node, &mut likelihood_operands, data, biases, joint_prob)
                 })
                 .collect_vec(),
-        );
-        p
+        )
     }
 }
 
